@@ -62,10 +62,6 @@ impl<T: Default> Default for Arc<T> {
     }
 }
 
-unsafe impl<T: Send + Sync> Send for Arc<T> {}
-
-unsafe impl<T: Send + Sync> Sync for Arc<T> {}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -127,4 +123,11 @@ mod tests {
             assert_eq!(*Arc::new(()), ());
         }
     }
+
+    fn drop_send_and_sync(_: impl Send + Sync) {}
+
+    #[test]
+    fn impelement_send_and_sync() {
+        drop_send_and_sync(Arc::new(()));
+    }
 }
